@@ -11,8 +11,7 @@ def test_impl(
     use_mypyc: bool = False,
 ):
     # Install deps and the package itself.
-    session.install("-U", "pip", "setuptools", silent=False)
-    session.install("-r", "dev-requirements.txt", silent=False)
+    session.install("-r", "dev-requirements.txt", "--require-hashes", silent=False)
 
     session.install(
         ".",
@@ -59,7 +58,7 @@ def test(session: nox.Session) -> None:
     test_impl(session)
 
 
-@nox.session(python=["3.7", "3.8", "3.9", "3.10", "3.11", "3.12", "3.13"])
+@nox.session(python=["3.7", "3.8", "3.9", "3.10", "3.11", "3.12", "3.13", "3.14"])
 def test_mypyc(session: nox.Session) -> None:
     test_impl(session, True)
 
@@ -87,8 +86,7 @@ def backward_compatibility(session: nox.Session) -> None:
     git_clone(session, "https://github.com/ousret/char-dataset")
 
     # Install deps and the package itself.
-    session.install("-U", "pip", "setuptools", silent=False)
-    session.install("-r", "dev-requirements.txt", silent=False)
+    session.install("-r", "dev-requirements.txt", "--require-hashes", silent=False)
 
     session.install(".", silent=False)
     session.install("chardet")
@@ -105,8 +103,7 @@ def coverage(session: nox.Session) -> None:
     git_clone(session, "https://github.com/ousret/char-dataset")
 
     # Install deps and the package itself.
-    session.install("-U", "pip", "setuptools", silent=False)
-    session.install("-r", "dev-requirements.txt", silent=False)
+    session.install("-r", "dev-requirements.txt", "--require-hashes", silent=False)
 
     session.install(".", silent=False)
 
@@ -133,8 +130,7 @@ def performance(session: nox.Session) -> None:
     git_clone(session, "https://github.com/ousret/char-dataset")
 
     # Install deps and the package itself.
-    session.install("-U", "pip", "setuptools", silent=False)
-    session.install("-r", "dev-requirements.txt", silent=False)
+    session.install("-r", "dev-requirements.txt", "--require-hashes", silent=False)
 
     session.install("chardet")
     session.install(".", silent=False, env={"CHARSET_NORMALIZER_USE_MYPYC": "1"})
